package com.agilefaqs.rft.suggestions.strategies;

import java.util.LinkedList;
import java.util.List;

import com.agilefaqs.rft.domain.UserService;
import com.agilefaqs.rft.suggestions.RandomNumberGenerator;
import com.agilefaqs.rft.suggestions.SuggestionsUtil;

public class ChildSuggestionFactory {

    private final List<ChildSuggestionStrategy> strategies = new LinkedList<ChildSuggestionStrategy>();
    private final List<ChildSuggestionStrategy> strategiesForSuggestionOne = new LinkedList<ChildSuggestionStrategy>();

    public ChildSuggestionFactory(final UserService userService, final SuggestionsUtil utils,
            final RandomNumberGenerator randomNumberGenerator) {
        final SimpleTokenStrategy simpleTokenStrategy = new SimpleTokenStrategy(userService, utils);
        final YearBasedStrategy yearBasedStrategy = new YearBasedStrategy(userService, utils);
        final RandomNumberBasedStrategy randomNumberBasedStrategy = new RandomNumberBasedStrategy(userService, utils,
                randomNumberGenerator);
        strategies.add(0, simpleTokenStrategy);
        strategies.add(1, new FirstNameAppendLastNameStrategy(userService, utils));
        strategies.add(2, new LastNameInitialStrategy(userService, utils));
        strategies.add(3, yearBasedStrategy);
        strategies.add(4, new LastNameInitialYearBasedStrategy(userService, utils));
        strategies.add(5, randomNumberBasedStrategy);

        strategiesForSuggestionOne.add(0, simpleTokenStrategy);
        strategiesForSuggestionOne.add(1, yearBasedStrategy);
        strategiesForSuggestionOne.add(2, randomNumberBasedStrategy);
    }

    public List<ChildSuggestionStrategy> getStrategies() {
        return strategies;
    }

    public List<ChildSuggestionStrategy> getChildStrategiesForSuggestionOne() {
        return strategiesForSuggestionOne;
    }

}
