package com.agilefaqs.rft.suggestions.strategies;

import com.agilefaqs.rft.domain.UserService;
import com.agilefaqs.rft.suggestions.IDTokens;
import com.agilefaqs.rft.suggestions.RandomNumberGenerator;
import com.agilefaqs.rft.suggestions.SuggestionsUtil;

public class RandomNumberBasedStrategy implements ChildSuggestionStrategy {

    private final UserService userService;
    private final SuggestionsUtil utils;
    private final RandomNumberGenerator randomNumberGenerator;

    public RandomNumberBasedStrategy(UserService userService, SuggestionsUtil utils, RandomNumberGenerator randomNumberGenerator) {
        this.userService = userService;
        this.utils = utils;
        this.randomNumberGenerator = randomNumberGenerator;
    }

    @Override
    public String generateId(ChildStrategyParam param) {
        final String token1 = param.getToken1();
        final String token2 = param.getToken2();
        IDTokens IdTokens = utils.getIdentityTokens(token1, token2);
        if (IdTokens == null) {
            return null;
        }
        String Identity = getIdentityBasedOnRandomNumber(IdTokens.getToken1(), IdTokens.getToken2());
        return Identity;
    }

    protected String getIdentityBasedOnRandomNumber(String token1, String token2) {
        String Identity = null;
        int attempt = 0;
        do {
            Identity = utils.appendTokensForId(token1.concat(randomNumberGenerator.next()), token2);
        } while (!userService.isIdentityAvailable(Identity) && ++attempt != 5);
        if (attempt == 5)
            return null;
        return Identity;
    }

}
