package com.agilefaqs.rft.suggestions;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

import org.junit.Test;

import com.agilefaqs.rft.domain.Country;
import com.agilefaqs.rft.domain.LocationInformation;
import com.agilefaqs.rft.domain.User;
import com.agilefaqs.rft.suggestions.SuggestionParam;

public class SuggestionParamTest {
    private static final String CITY = "mumbai";
    private static final String COUNTRY_NAME = "india";
    private static final String COUNTRY_MONIKER = "indian";
    private static final String FIRST_NAME = "Naresh";
    private static final String LAST_NAME = "Jain";
    private static final String CITY2 = "blor";
    private final Country country = new Country("IN", COUNTRY_NAME, COUNTRY_MONIKER);

    @Test
    public void testEquals() throws Exception {
        SuggestionParam paramOne = new SuggestionParam(new LocationInformation(country, CITY), FIRST_NAME, LAST_NAME);
        SuggestionParam paramTwo = new SuggestionParam(new LocationInformation(country, CITY2), FIRST_NAME, LAST_NAME);
        SuggestionParam paramThree = new SuggestionParam(new LocationInformation(country, CITY), FIRST_NAME, LAST_NAME);
        assertTrue(paramOne.equals(paramThree));
        assertFalse(paramOne.equals(paramTwo));
        assertFalse(paramThree.equals(paramTwo));
        assertFalse(paramThree.equals(null));
        assertFalse(paramThree.equals(new User()));
    }

    @Test
    public void shouldTrimSpecialCharacters() throws Exception {
        SuggestionParam paramOne = new SuggestionParam(new LocationInformation(country, CITY), "peppy*pa%", "#pat-el-");
        assertEquals(paramOne.getValidFirstNameToken(), "peppypa");
        assertEquals(paramOne.getValidLastNameToken(), "pat-el");
    }

    @Test
    public void shouldAppendLettersIfRequired() throws Exception {
        SuggestionParam paramOne = new SuggestionParam(new LocationInformation(country, CITY), "pe%", "pa");
        assertEquals(paramOne.getValidFirstNameToken(), "pepe");
        assertEquals(paramOne.getValidLastNameToken(), "papa");
    }

    @Test
    public void truncateLettersIfRequired() throws Exception {
        SuggestionParam paramOne = new SuggestionParam(new LocationInformation(country, CITY), "suchalongnameuhavegiven", "pa");
        assertEquals(paramOne.getValidFirstNameToken(), "suchalongnameuh");
        assertEquals(paramOne.getValidLastNameToken(), "papa");
    }

}
