package com.agilefaqs.rft.suggestions.strategies;

import static org.easymock.EasyMock.expect;
import static org.easymock.classextension.EasyMock.createMock;
import static org.easymock.classextension.EasyMock.replay;
import static org.easymock.classextension.EasyMock.reset;
import static org.easymock.classextension.EasyMock.verify;
import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNull;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;

import com.agilefaqs.rft.domain.UserService;
import com.agilefaqs.rft.suggestions.IDTokens;
import com.agilefaqs.rft.suggestions.SuggestionsUtil;
import com.agilefaqs.rft.suggestions.strategies.ChildStrategyParam;
import com.agilefaqs.rft.suggestions.strategies.SimpleTokenStrategy;

public class SimpleTokenStrategyTest {
    private static final String FIRST_NAME = "Naresh";
    private static final String LAST_NAME = "Jain";
    private final ChildStrategyParam childStrategyParam = new ChildStrategyParam(FIRST_NAME, LAST_NAME, null);

    private final String Identity = FIRST_NAME.concat("@").concat(LAST_NAME).concat(".com");
    private final SuggestionsUtil suggestionUtil = createMock(SuggestionsUtil.class);
    private final UserService userService = createMock(UserService.class);
    private final SimpleTokenStrategy simpleTokenStrategy = new SimpleTokenStrategy(userService, suggestionUtil);

    @Before
    public void setUp() {

        reset(userService, suggestionUtil);
    }

    @Test
    public void shouldGenerateSuggestionBasedOnYearStratey() throws Exception {
        final String token1 = childStrategyParam.getToken1();
        final String token2 = childStrategyParam.getToken2();
        expect(suggestionUtil.getIdentityTokens(token1, token2)).andReturn(new IDTokens(token1, token2));
        expect(suggestionUtil.appendTokensForId(token1, token2)).andReturn(Identity);
        expect(userService.isIdentityAvailable(Identity)).andReturn(true);
        stopRecordingAndStartReplay();
        String Id = simpleTokenStrategy.generateId(childStrategyParam);
        assertEquals(Id, Identity);
    }

    @Test
    public void shouldReturnNullIfIdIsNotAvailable() throws Exception {
        final String token1 = childStrategyParam.getToken1();
        final String token2 = childStrategyParam.getToken2();
        expect(suggestionUtil.getIdentityTokens(token1, token2)).andReturn(null);
        stopRecordingAndStartReplay();
        String generatedId = simpleTokenStrategy.generateId(childStrategyParam);
        assertNull(generatedId);
    }

    @Test
    public void shouldReturnNullIfIdTokenReturnedBySuggestionUtilIsNullBasedOnYearStratey() throws Exception {
        final String token1 = childStrategyParam.getToken1();
        final String token2 = childStrategyParam.getToken2();
        expect(suggestionUtil.getIdentityTokens(token1, token2)).andReturn(new IDTokens(token1, token2));
        expect(suggestionUtil.appendTokensForId(token1, token2)).andReturn(Identity);
        expect(userService.isIdentityAvailable(Identity)).andReturn(false);
        stopRecordingAndStartReplay();
        String generatedId = simpleTokenStrategy.generateId(childStrategyParam);
        assertNull(generatedId);
    }

    @After
    public void verifyMocks() {
        verify(userService, suggestionUtil);
    }

    private void stopRecordingAndStartReplay() {
        replay(suggestionUtil, userService);
    }

}
